summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/filecreate_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/filecreate_part.h')
-rw-r--r--parts/filecreate/filecreate_part.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/parts/filecreate/filecreate_part.h b/parts/filecreate/filecreate_part.h
index 3cbc9909..605f6fbf 100644
--- a/parts/filecreate/filecreate_part.h
+++ b/parts/filecreate/filecreate_part.h
@@ -14,10 +14,10 @@
#define __KDEVPART_FILECREATE_H__
-#include <qguardedptr.h>
-#include <qptrlist.h>
+#include <tqguardedptr.h>
+#include <tqptrlist.h>
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kdevplugin.h>
#include <kdevcreatefile.h>
@@ -42,36 +42,36 @@ class FileCreatePart : public KDevCreateFile
friend class FCConfigWidget;
public:
- FileCreatePart(QObject *parent, const char *name, const QStringList &);
+ FileCreatePart(TQObject *parent, const char *name, const TQStringList &);
virtual ~FileCreatePart();
/**
* Returns the list of available file types.
*/
- QPtrList<FileType> getFileTypes() const { return m_filetypes; }
+ TQPtrList<FileType> getFileTypes() const { return m_filetypes; }
/**
* Call this method to create a new file, within or without the project. Supply as
* much information as you know. Leave what you don't know as QString::null.
* The user will be prompted as necessary for the missing information, and the
* file created, and added to the project as necessary.
*/
- virtual KDevCreateFile::CreatedFile createNewFile(QString ext = QString::null,
- QString dir = QString::null,
- QString name = QString::null,
- QString subtype = QString::null);
+ virtual KDevCreateFile::CreatedFile createNewFile(TQString ext = TQString::null,
+ TQString dir = TQString::null,
+ TQString name = TQString::null,
+ TQString subtype = TQString::null);
/**
* Finds the file type object for a given extension and optionally subtype.
* You can omit the subtype and specify the extension as ext-subtype if you wish.
*/
- FileType * getType(const QString & ext, const QString subtype = QString::null);
+ FileType * getType(const TQString & ext, const TQString subtype = TQString::null);
/**
* Finds the file type object for a given extension and optionally subtype.
* You can omit the subtype and specify the extension as ext-subtype if you wish.
* Returns only enabled type (i.e. used in the project).
*/
- FileType * getEnabledType(const QString & ext, const QString subtype = QString::null);
+ FileType * getEnabledType(const TQString & ext, const TQString subtype = TQString::null);
public slots:
@@ -99,7 +99,7 @@ public slots:
protected slots:
void slotNoteFiletype(const FileType * filetype);
void slotAboutToShowNewPopupMenu();
- void insertConfigWidget( const KDialogBase * dlg, QWidget * page, unsigned int );
+ void insertConfigWidget( const KDialogBase * dlg, TQWidget * page, unsigned int );
private:
/**
@@ -112,22 +112,22 @@ private:
* to the file type list. If enable is true, sets them all to
* enabled=true by default.
*/
- int readTypes(const QDomDocument & dom, QPtrList<FileType> &m_filetypes, bool enable);
+ int readTypes(const TQDomDocument & dom, TQPtrList<FileType> &m_filetypes, bool enable);
/**
* Add a file type
*/
- void addFileType(const QString & filename);
+ void addFileType(const TQString & filename);
/**
* Finds the global XML file that has the same version as KDevelop
*/
- QString findGlobalXMLFile() const;
+ TQString findGlobalXMLFile() const;
/**
* List of file types from which the user can choose
*/
- QPtrList<FileType> m_filetypes;
+ TQPtrList<FileType> m_filetypes;
/**
* The file type selected by the new file dialog, if appropriate.
@@ -137,7 +137,7 @@ private:
ConfigWidgetProxy * _configProxy;
KPopupMenu* m_newPopupMenu;
- QPtrList<KPopupMenu>* m_subPopups;
+ TQPtrList<KPopupMenu>* m_subPopups;
};
@@ -42,36 +42,36 @@ class FileCreatePart : public KDevCreateFile
/**
* Call this method to create a new file, within or without the project. Supply as
- * much information as you know. Leave what you don't know as QString::null.
+ * much information as you know. Leave what you don't know as TQString::null.
* The user will be prompted as necessary for the missing information, and the
* file created, and added to the project as necessary.